engine

package
v0.0.0-...-3453aac Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 15, 2026 License: Apache-2.0 Imports: 16 Imported by: 2

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CalculateAgentUniqueId

func CalculateAgentUniqueId() (string, error)

func GetEvidence

func GetEvidence() (string, error)

func GetEvidenceWithAgentUuid

func GetEvidenceWithAgentUuid() ([]byte, error)

func GetEvidenceWithCCUrl

func GetEvidenceWithCCUrl() ([]byte, error)

Types

type Engine

type Engine struct {
	// contains filtered or unexported fields
}

func NewEngine

func NewEngine() *Engine

func (*Engine) Close

func (e *Engine) Close()

Close terminates the engine's resources by closing the underlying runner. It should be called to clean up resources when the engine is no longer needed.

func (*Engine) LoadWasm

func (e *Engine) LoadWasm(wasmBytes []byte) error

LoadWasm loads and instantiates a WASM module from the given byte slice. It sets up the necessary host functions (including logging) and WASI environment. The instantiated module is stored in the Engine for later execution. Returns an error if the WASM module fails to instantiate.

func (*Engine) OnAttestationCollect

func (e *Engine) OnAttestationCollect() (attestation string)

func (*Engine) OnAttestationVerify

func (e *Engine) OnAttestationVerify(attestation string) bool

func (*Engine) OnDataPostprocess

func (e *Engine) OnDataPostprocess(rawOutput string) (processedOutput string)

func (*Engine) OnDataPreprocess

func (e *Engine) OnDataPreprocess(metadata string, rawData string, filter string) (processedData string)

func (*Engine) ReadContentFromVMMemory

func (e *Engine) ReadContentFromVMMemory(memPos uint32, memLen uint32) []byte

func (*Engine) WriteContentToVMMemory

func (e *Engine) WriteContentToVMMemory(content string) (memPos uint64, memLen uint64)

Jump to