Documentation
¶
Index ¶
- func CalculateAgentUniqueId() (string, error)
- func GetEvidence() (string, error)
- func GetEvidenceWithAgentUuid() ([]byte, error)
- func GetEvidenceWithCCUrl() ([]byte, error)
- type Engine
- func (e *Engine) Close()
- func (e *Engine) LoadWasm(wasmBytes []byte) error
- func (e *Engine) OnAttestationCollect() (attestation string)
- func (e *Engine) OnAttestationVerify(attestation string) bool
- func (e *Engine) OnDataPostprocess(rawOutput string) (processedOutput string)
- func (e *Engine) OnDataPreprocess(metadata string, rawData string, filter string) (processedData string)
- func (e *Engine) ReadContentFromVMMemory(memPos uint32, memLen uint32) []byte
- func (e *Engine) WriteContentToVMMemory(content string) (memPos uint64, memLen uint64)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CalculateAgentUniqueId ¶
func GetEvidence ¶
func GetEvidenceWithCCUrl ¶
Types ¶
type Engine ¶
type Engine struct {
// contains filtered or unexported fields
}
func (*Engine) Close ¶
func (e *Engine) Close()
Close terminates the engine's resources by closing the underlying runner. It should be called to clean up resources when the engine is no longer needed.
func (*Engine) LoadWasm ¶
LoadWasm loads and instantiates a WASM module from the given byte slice. It sets up the necessary host functions (including logging) and WASI environment. The instantiated module is stored in the Engine for later execution. Returns an error if the WASM module fails to instantiate.
func (*Engine) OnAttestationCollect ¶
func (*Engine) OnAttestationVerify ¶
func (*Engine) OnDataPostprocess ¶
func (*Engine) OnDataPreprocess ¶
func (*Engine) ReadContentFromVMMemory ¶
Click to show internal directories.
Click to hide internal directories.